# support for the ftpmail system
# By Lee McLoughlin <lmjm@doc.ic.ac.uk>
#  You can do what you like with this except claim that you wrote it or
#  give copies with changes not approved by Lee.  Neither Lee nor any other
#  organisation can be held liable for any problems caused by the use or
#  storage of this package.
#

# Don't change this unless you are really clever.
$ftpmail_response = '<FTP EMAIL> response';


# Expects globals $qfile, $reply_to, $tries, and @comms
# If updating_only is set then the file will not be recreated only updated.
sub write_entry
{
	if( $updating_only && ! -f $qfile ){
		# Job must have been deleted
		return;
	}
	open( qfile, "> $qfile" ) || die "Cannot create queue entry";;
	&update_entry();
	close( qfile );
}

sub update_entry
{
	local( $c );

	local( $to ) = $reply_to;
	$to =~ s/\\\@/@/;
	seek( qfile, 0, 0 );
	print qfile "reply-to $to\n";
	print qfile "tries $tries $whenretry\n";
	foreach $c ( @comms ){
		print qfile "$c\n";
	}
	print qfile "\n";
}

sub scan_q
{
	local( $ahead ) = @_;

	&log( "scanning queue" ) if $verbose;
	
	@qfiles = ();
	opendir( dir, $quedir ) || die "Cannot open directory: $quedir";
	local( @dir ) = readdir( dir );
	closedir( dir );

	foreach $_ ( @dir ){
		if( /^(\d)\d+\.\d+$/ ){
			local( $prio ) = $1;
			next if defined( $ahead ) && $prio > $ahead;
			push( @qfiles, $_ );
		}
	}
	@qfiles = sort @qfiles;
}


# Pretty print the contents of the comms array to MAIL
sub mail_comms
{
	local( $c );
	local( $site, $user, $pass );
	local( $show_open ) = 1;

	print MAIL "      reply-to $reply_to\n";
	foreach $_ ( @comms ){
		if( /^open (.+)$/i ){
			$site = $1;
			next;
		}
		elsif( /^user (.+)$/i ){
			$user = $1;
			next;
		}
		elsif( /^pass (.+)$/i ){
			$pass = $1;
			next;
		}
		if( $show_open ){
			print MAIL "      open $site $user $pass\n";
			$show_open = 0;
		}
		local( $l ) = $_;
		if( $l !~ /DONE/ ){
			$l =~ s/^/     /;
		}
		print MAIL " $l\n";
	}
}

# print the MAIL any contents of the ftpmail message of the day file
sub mail_motd
{
	if( open( motd, $motdfile ) ){
		while( <motd> ){
			print MAIL;
		}
		close( motd );
	}
}

sub fail
{
	local( $fatal_error ) = @_;

	die( "Fatal error $fatal_error, probably due to config problems" );
}

sub fatal
{
	local( $fatal_error ) = @_;

	&log( "Fatal error $fatal_error" );
	exit( 0 );
}

sub log
{
	local( $msg ) = @_;

	&gettime();

	open( LOG, ">>$logfile" ) || die "$logfile: cannot open: $!\n";
	local( $q );
	if( defined( $slot ) && $max_dqs > 0 ){
		$q = "[$slot] ";
	}
	print LOG "$time $q$msg\n";
	close( LOG );
}

sub gettime
{
    ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) =
						localtime(time);
    $time = sprintf( "%02d/%02d/%02d %02d:%02d:%02d",
		    $year, $mon+1, $mday, $hour, $min, $sec );
}

#  Make sure this package returns TRUE
1;
